ConnectivityInfo class

Immutable class containing information about the current network connectivity.

This class provides details about connection status, quality, timing, and optional endpoint information for connectivity checks.

Annotations

Constructors

ConnectivityInfo({required ConnectivityStatus status, required ConnectionQuality quality, required DateTime timestamp, String? endpoint, Duration? latency})
const

Properties

endpoint String?
final
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
isDisconnected bool
no setter
latency Duration?
final
quality ConnectionQuality
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ConnectivityStatus
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited