ConnectivityManager class

Constructors

ConnectivityManager({List<String> checkEndpoints = const ['https://www.google.com', 'https://www.cloudflare.com', '1.1.1.1'], Duration checkInterval = const Duration(seconds: 10), Duration timeout = const Duration(seconds: 5), bool manualOverride = true})

Properties

checkEndpoints List<String>
final
checkInterval Duration
final
currentStatus ConnectivityInfo
no setter
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
isOffline bool
no setter
manualOverride bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusStream Stream<ConnectivityInfo>
no setter
timeout Duration
final

Methods

checkConnectivity() Future<ConnectivityInfo>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setManualOfflineMode(bool offline) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited