NetworkFirstCachePolicy class final

Inheritance
Annotations

Constructors

NetworkFirstCachePolicy({Duration? ttl = const Duration(minutes: 5), Set<String> cacheMethods = const {'GET', 'HEAD'}, Set<int> cacheStatusCodes = const {200, 201, 204, 300, 301, 302, 404, 410}})
const

Properties

cacheMethods Set<String>
final
cacheStatusCodes Set<int>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldCache(String method, int statusCode) bool
override
shouldUseCache(String method) bool
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited